#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location    : http://galculator.sourceforge.net/
# last revised       : 9/02/09

softname='galculator'
softversion='1.3.4'
packageversion='64.1'

arch='i486'
cpu='i686'

prefix=/usr

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://mesh.dl.sourceforge.net/sourceforge/galculator/$softname-$softversion.tar.bz2

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/icons/hicolor/scalable/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: GTK2+ Calculator
$softname: 
$softname: Galculator, a simple gtk2+ based calculator, 
$softname: simple and easy to use. 
$softname: 
$softname: 
$softname: 
$softname: 
$softname: 
$softname:
$softname: 
EOF

#
# Verifie si package est present
#
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xjvf $srcpkg
cd $src

# configure package and install it to the target directory

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --mandir=$prefix/man \
      --build=$arch-slackware-linux

    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      ABOUT-NLS AUTHORS COPYING INSTALL NEWS README ChangeLog THANKS TODO \
      $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress Man Pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# make the .desktop file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop 
[Desktop Entry]
Name=Galculator
Name[fr]=Calculatrice
Comment=Perform simple and scientific calculations
Comment[de]=Ausführen von einfachen und wissenschaftlichen Berechnungen
Comment[fr]=Effectue des calculs simples ou scientifiques
Comment[ja]=単純な科学計算を実行します
Comment[pl]=Wykonaj proste lub naukowe obliczenia
Comment[pt_BR]=Executa cálculos simples e científicos
Exec=galculator
Icon=galculator
Terminal=false
Type=Application
Categories=Application;Utility;
StartupNotify=true
Encoding=UTF-8
EOF

# Make the package freedesktop compliant
cp $dest/usr/share/pixmaps/$softname.svg $dest/usr/share/icons/hicolor/scalable/apps/$softname.svg

# put the ZenWalk build in the right directory
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "atk,cairo,cxxlibs|gcc-g++,expat,fontconfig,freetype,gcc,\
glib2,gtk+2,libX11,libXau,libXcomposite,libXcursor,libXdamage,\
libXdmcp,libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,\
libglade,libpng,libxcb,libxml2,pango,pixman,zlib" > $package.dep

#
# src file
#
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/xap/galculator/source/build-galculator.sh > $package.src
echo $source >> $package.src

#
# supprimer source
#
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
